@@ -1,3 +1,4 @@
+import csv
 import json
 import os
 from datetime import datetime
@@ -454,8 +455,10 @@ def logiclike_get_full_all_chapter(username, password, chapter_ids, output):
 @codesignal_group.command(name="tournament-result")
 @click.option('-c', '--credential', default='credentials.ini',
               type=click.Path(dir_okay=False, exists=True), help='Configuration file that contain airtable credential')
+@click.option('-u', '--user_map', default='user_map.csv',
+              type=click.Path(dir_okay=False, exists=True), help='codesignal\'s username - fullname mapping')
 @click.argument("tournament", metavar='{tournament id or url}')
-def codesignal_get_tournament_result(tournament, credential=None):
+def codesignal_get_tournament_result(tournament, credential=None, user_map=None):
     cs = Codesignal()
     tour_info, tour_standing = cs.get_tournament_result(tournament)
     # tournament_id = tour_info['id']
@@ -465,8 +468,17 @@ def codesignal_get_tournament_result(tournament, credential=None):
     # print(f"Tournament task ids: `{tournament_task_ids}`")
     # print(f"Tournament standing: {len(tour_standing)}", json.dumps(tour_standing))
 
+    print(f"\n\nTournament: https://app.codesignal.com/tournaments/{tour_info['id']}")
+    print(f"\nStarted at: {datetime.fromtimestamp(tour_info['fields']['startDate'] // 1000).isoformat()}")
+
     tour_json = cs.tournament_standing_format(tour_info, tour_standing)
-    print(json.dumps(tour_json, indent=2))
+    print(cs.tournament_json_to_ascii_table(tour_json))
+
+    tour_standing = cs.re_judge(tour_standing)
+    tour_json = cs.tournament_standing_format(tour_info, tour_standing)
+    print(f"\n\nREJUDGE result:\n")
+    print(cs.tournament_json_to_ascii_table(tour_json))
+
     if credential:
         pass
         api_key, base_id, table = Airtable.read_credential(credential)
@@ -474,16 +486,8 @@ def codesignal_get_tournament_result(tournament, credential=None):
             CLog.error(f'AIRTABLE api_key, base_id or table are missing in {credential} file')
         else:
             airtable = Airtable(api_key=api_key, base_id=base_id, table_name=table)
-            cs.tournament_standing_to_airtable(tour_json, airtable)
+            users = None
+            if user_map:
+                users = cs.read_user_map(user_map)
 
-    print(f"\n\nTournament: https://app.codesignal.com/tournaments/{tour_info['id']}")
-    print(f"\nStarted at: {datetime.fromtimestamp(tour_info['fields']['startDate']//1000).isoformat()}")
-    header = ["#", "User", "Country", "A", "B", "C", "D", "E", "Score", "Time", "XP"]
-    table = []
-    for item in tour_json:
-        table.append([
-            item['rank'], item['username'], item['country'], item['A'], item['B'], item['C'], item['D'], item['E'],
-            item['score'], f"{item['time']//60}:{item['time']%60:02d}", item['xp']
-        ])
-
-    print(tabulate(table, headers=header))
+            cs.tournament_standing_to_airtable(tour_json, airtable, users)
