@@ -1,11 +1,11 @@
 import copy
 import html
+import pickle
 
 import requests
 import tomd
 from bs4 import BeautifulSoup
 
-from ptoolbox.dsa.dsa_problem import DsaProblem
 from ptoolbox.helpers.clog import CLog
 from ptoolbox.models.general_models import Problem, TestCase
 
@@ -62,8 +62,16 @@ class Codeforces:
         self.s = requests.session()
         self._headers = {
             'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36',
+            'origin': "https://codeforces.com",
+            'referer': "https://codeforces.com/enter",
+            'sec-fetch-dest': "empty",
+            'sec-fetch-mode': "cors",
+            'sec-fetch-site': "same-origin",
+            'x-requested-with': "XMLHttpRequest"
         }
         self.csrf = ''
+        self.evercookie = "67ano0cpxyd6bygc7w"
+        self.bfaa = "a60708ec87a45f5b510d7ab2b81a9044"
 
     def get_problem_list(self, page_index):
         url = f'https://codeforces.com/problemset/page/{page_index}'
@@ -436,9 +444,141 @@ class Codeforces:
         self.csrf = soup.select('span.csrf-token')[0]['data-csrf']
         # print('CSRF:', self.csrf)
 
+    def login(self, username, password):
+        headers = copy.deepcopy(self._headers)
+        r = self.s.get("https://codeforces.com/enter", headers=headers)
+        # print(r.text)
+
+        print("cookies:")
+        for c in r.cookies:
+            print(c.name, c.value)
+
+        soup = BeautifulSoup(r.text, 'html.parser')
+        csrf = soup.select('meta[name="X-Csrf-Token"]')[0]['content']
+        self.csrf = csrf
+        self._headers["x-csrf-token"] = csrf
+        print("csrf: ", csrf)
+
+        url = "https://codeforces.com/2fdcd78/ees?name=70a7c28f3de&cookie=evercookie_etag"
+        r = self.s.get(url, headers=headers)
+        print(r.text)
+        print("evercookie_etag 1 status code:", r.status_code)
+        print("res header:", r.headers)
+
+        url = "https://codeforces.com/2fdcd78/ecs?name=70a7c28f3de&cookie=evercookie_cache"
+        r = self.s.get(url, headers=headers)
+        print(r.text)
+        print("evercookie_cache 1 status code:", r.status_code)
+
+        payload = {
+            "bfaa": self.bfaa,
+            "ftaa": "",
+            "csrf_token": csrf
+        }
+
+        headers = copy.deepcopy(self._headers)
+        # self.s.mount('https://codeforces.com', HTTP20Adapter())
+        r = self.s.post("https://codeforces.com/data/empty", data=payload, headers=headers)
+        print("data/empty 1 status code:", r.status_code)
+        print("req headers:", headers)
+        # dataraw = ""
+        # for chunk in (r.iter_content()):
+        #     print("chunk", chunk)
+        # print(dataraw)
+        print(r.text)
+        # print("res headers:", r.headers)
+        # for k in r.headers:
+        #     print(k, ":", r.headers[k])
+        print("cookies:")
+        # for c in r.cookies:
+        #     print(c.name, c.value)
+
+        my_cookies = {
+            "evercookie_png": self.evercookie,
+            "evercookie_etag": self.evercookie,
+            "evercookie_cache": self.evercookie
+        }
+        # my_cookie = requests.cookies.create_cookie(**self.s.cookies, **optional_args)
+        requests.utils.add_dict_to_cookiejar(self.s.cookies, my_cookies)
+        # self.s.cookies.set_cookie(my_cookie)
+        print(self.s.cookies)
+
+        url = "https://codeforces.com/2fdcd78/ees?name=70a7c28f3de&cookie=evercookie_etag"
+        r = self.s.get(url, headers=headers)
+        print("evercookie_etag 2 status code:", r.status_code)
+        print(r.text)
+        print("res header:", r.headers)
+
+        url = "https://codeforces.com/2fdcd78/ecs?name=70a7c28f3de&cookie=evercookie_cache"
+        r = self.s.get(url, headers=headers)
+        print(r.text)
+        print("evercookie_cache 2 status code:", r.status_code)
+        print("res header:", r.headers)
+
+        payload = {
+            "bfaa": self.bfaa,
+            "ftaa": self.evercookie,
+            "csrf_token": csrf
+        }
+
+        r = self.s.post("https://codeforces.com/data/empty", data=payload, headers=headers)
+        print("data/empty 2 status code:", r.status_code)
+        print("req headers:", headers)
+        print(r.text)
+
+        url = "https://codeforces.com/enter"
+        payload = {
+            "bfaa": self.bfaa,
+            "ftaa": self.evercookie,
+            "action": "enter",
+            "csrf_token": csrf,
+            "handleOrEmail": username,
+            "password": password
+        }
+        #
+        r = self.s.post(url, data=payload, headers=headers)
+        # print(r.text)
+        print("status code:", r.status_code)
+        # print("cookies:")
+        # for c in r.cookies:
+        #     print(c.name, c.value)
+        print(pickle.dumps(self.s))
+
+    def submit(self, contest_id, submitted_problem_index, program_type_id, source, tab_size=4):
+        url = f"https://codeforces.com/problemset/submit?csrf_token={self.csrf}"
+        payload = {
+            "csrf_token": self.csrf,
+            "bfaa": self.bfaa,
+            "ftaa": self.evercookie,
+            "action": "submitSolutionFormSubmitted",
+            "contestId": contest_id,
+            "submittedProblemIndex": submitted_problem_index,
+            "programTypeId": program_type_id,
+            "source": source,
+            "tabSize": tab_size,
+            "sourceFile": "",
+            "_tta": 836,
+        }
+        my_cookies = {
+            "lastOnlineTimeUpdaterInvocation": "1602201189155",
+            "X-User-Sha1": "bbc325ea8f12e85b1e918dacdf8cb36016bfeabd"
+        }
+        # my_cookie = requests.cookies.create_cookie(**self.s.cookies, **optional_args)
+        requests.utils.add_dict_to_cookiejar(self.s.cookies, my_cookies)
+        print(self.s.cookies)
+        headers = copy.deepcopy(self._headers)
+        r = self.s.post(url, data=payload, headers=headers)
+        print(r.text)
+        print("status code:", r.status_code)
+        print("cookies:")
+        for c in r.cookies:
+            print(c.name, c.value)
+
 
 if __name__ == '__main__':
     cf = Codeforces()
+    cf.login("thucnc", "15041985")
+    cf.submit(contest_id=4, submitted_problem_index="A", program_type_id=31, source="print('YES')")
     # problems, page_count = cf.get_problem_list(1)
     # CLog.info("Number of pages: %s" % page_count)
     #
@@ -451,7 +591,7 @@ if __name__ == '__main__':
     # dsa_problem = cf.get_problem_detail(problems[4])
 
     # dsa_problem = cf.get_problem_from_url("https://codeforces.com/problemset/problem/1257/C")
-    dsa_problem = cf.get_problem_from_url("1268/B")
-    DsaProblem.save(dsa_problem, "../problems", overwrite=True)
+    # dsa_problem = cf.get_problem_from_url("1268/B")
+    # DsaProblem.save(dsa_problem, "../problems", overwrite=True)
     # print(dsa_problem)
 
