@@ -325,7 +325,7 @@ class Codesignal:
         :param csv_file:
         :return:
         """
-        with open(csv_file) as csv_file:
+        with open(csv_file, encoding="utf8") as csv_file:
             reader = csv.reader(csv_file, delimiter='\t')
             users = {}
             for row in reader:
@@ -378,7 +378,7 @@ class Codesignal:
 
 if __name__ == '__main__':
     # uri = "https://app.codesignal.com/tournaments/WmYmJ3ydfHAomAZaq"
-    uri = "https://app.codesignal.com/tournaments/MRkDYWPBMbEb2mdER"
+    uri = "https://app.codesignal.com/tournaments/viwukyIq8RuHP7v1x"
     # uri = "wss://app.codesignal.com/sockjs/885/ikhnrug9/websocket"
     cs = Codesignal()
     tour_info, tour_standing = cs.get_tournament_result(uri)
