@@ -621,9 +621,9 @@ class HackerRankTrack:
 if __name__ == "__main__":
     # prepare_testcases("../problems/prob1", True)
     hr = HackerRank()
-    # hr.login('thucngch', '15041985')       # ucodevn02
+    hr.login('thucngch', '15041985')       # ucodevn02
     # hr.login('nguyenchithuc', 'ngoaho85')  # ucodet02
-    hr.login('ucodevn', 'ucode@123')         # ucode02
+    # hr.login('ucodevn', 'ucode@123')         # ucode02
 
     hr.create_contest("ucode")
 
