@@ -3,19 +3,23 @@ import logging
 import os
 from distutils.dir_util import copy_tree
 
+from typing import List, Tuple
+
 from ptoolbox.codeforces.codeforces import Codeforces
-from ptoolbox.dsa.dsa_problem import DsaProblem
 
 __author__ = 'ThucNC'
 
+from ptoolbox.dsa.dsa_problem import DsaProblem
+
 from ptoolbox.helpers.misc import make_problem_code
 
 from ptoolbox.kattis.kattis import Kattis
+from ptoolbox.models.general_models import Problem
 
 _logger = logging.getLogger(__name__)
 
 
-def read_all_problems(base_folder, nested_folder=0, load_testcase=False, translations=[]):
+def read_all_problems(base_folder, nested_folder=0, load_testcase=False, translations=[]) -> List[Tuple[str, Problem]]:
     res = []
     problem_folders = [f.path for f in os.scandir(base_folder) if f.is_dir()]
     for problem_folder in sorted(problem_folders):
