@@ -1,4 +1,5 @@
 # coding=utf-8
+import base64
 import logging
 
 __author__ = 'ThucNC'
@@ -25,4 +26,12 @@ def make_problem_code(name):
     name = name.strip(" _").replace("-", "_")
     if '0' <= name[0] <= '9':
         name = "p" + name
-    return name
\ No newline at end of file
+    return name
+
+
+def base64_encode(data: str) -> str:
+    return base64.b64encode(data.encode('utf-8')).decode('utf-8')
+
+
+def base64_decode(data: str) -> str:
+    return base64.b64decode(data.encode('utf-8')).decode('utf-8')
\ No newline at end of file
