@@ -2,6 +2,8 @@ import copy
 import pprint
 from enum import Enum
 
+from typing import List
+
 
 class ProblemType(Enum):
     code = "code"
@@ -75,15 +77,15 @@ class TestCase:
 class Problem:
     def __init__(self):
         self.src_id = ""
-        self.translations = {}
+        self.translations: List[Problem] = {}
         self.src_url = ""
         self.src_name = ""
         self.src_status_url = ""
         self.src_data = None
         self.input_type = 'stdin'
         self.output_type = 'stdout'
-        self.limit_time = 10000 # ms
-        self.limit_memory = 256 # MB
+        self.limit_time = 1000 # ms
+        self.limit_memory = 64 # MB
         self.name = ""
         self.slug = ""
         self.code = ""
@@ -91,8 +93,12 @@ class Problem:
         self.template = ""  # editor template
         self.preview = ""
         self.statement = self.src_id = ""
+        self.statement_language = "vi"
+        self.statement_format = "markdown"
         self.input_format = self.constraints = self.output_format = ""
         self.judge_mode = JudgeMode.oj
+        self.xp = 100
+        self.testcase_format = "ucode"
         self.testcases_sample = []
         self.stock_testcases_sample = []
         self.testcases = []
@@ -106,6 +112,7 @@ class Problem:
         self.contest_slug = None    # hackerrank specific
         self.topics = []
         self.tags = []
+        self.testcase_generator = {}  # {"lang"="", "code"=".."}
         self.experience_gain = 0
         self.difficulty = 0.0
         self.difficulty_level = ProblemDifficulty.easy
@@ -114,7 +121,7 @@ class Problem:
         self.public_test_cases = False
         self.public_solutions = False
         self.languages = []
-        self.solutions = []  # list of solution for each language
+        self.solutions = []  # list of solution for each language: [{'lang': '11.cpp', 'code': "..."}]
         self.hints = []  # list of hint for each language
         self.track = None # hackerrank specific
 
@@ -199,6 +206,9 @@ class Classroom:
         s = "src_id: " + str(self.src_id) + "\n"
         s += "Name: " + self.name + "\n"
         s += "Language: " + str(self.language)
+        s += "\nNo of assignments: " + str(len(self.assignments))
+        s += "\nNo of scheduled_assignments: " + str(len(self.scheduled_assignments))
+        s += "\nNo of draft_assignments: " + str(len(self.draft_assignments))
         s += "\nNo of students: " + str(len(self.students))
         s += "\nNo of student_invites: " + str(len(self.student_invites))
         s += "\nNo of self_learners: " + str(len(self.self_learners))
