@@ -10,6 +10,7 @@ from typing import List, Union
 import requests
 
 from ptoolbox.beestar.beestar import Beestar
+from ptoolbox.helpers.dsa_helper import read_all_problems
 from ptoolbox.iqsha.iqsha import IQSha
 from ptoolbox.dsa.dsa_problem import DsaProblem
 from ptoolbox.hackerrank.hackerrank import HackerRank, prepare_testcases
@@ -34,14 +35,14 @@ class UCode:
         return self.api_base_url + path
 
     def create_problem(self, lesson_id, problem: Union[Question, Problem, str],
-                       score=10, xp=100, lang='vi', statement_format="markdown", question_type='code',
-                       is_server_judge=0):
+                       score=100, xp=100, lang='vi', statement_format="markdown", question_type='code',
+                       is_server_judge=True, status="published"):
         """
 
         :param lesson_id:
         :param problem:
         :param score:
-        :param xp:
+        :param xp: -1 để tự động tính theo độ khó
         :param lang:
         :param statement_format:
         :param question_type: multiple_choice, short_answer, code, turtle, sport
@@ -51,6 +52,9 @@ class UCode:
             problem: Problem = DsaProblem.load(problem, load_testcase=True)
 
         if isinstance(problem, Problem):
+            ucoin = xp
+            if ucoin<0:
+                ucoin = int(round(50 * problem.difficulty, -2))
             data = {
                 "name": problem.name,
                 "type": question_type,
@@ -63,16 +67,19 @@ class UCode:
                 "statement_language": lang,
                 "score": score,
                 "solution": problem.solution,
-                "status": "published",
+                "difficulty": problem.difficulty,
+                "status": status,
                 "visibility": "public",
-                "ucoin": xp,
+                "ucoin": ucoin,
                 'is_server_judge': is_server_judge
             }
+            if not lesson_id:
+                data['tags'] = problem.tags
         elif isinstance(problem, Question):
             question: Question = problem
             data = {
                 "name": question.src_name,
-                "type": question.type.value or type,
+                "type": question.type.value or question_type,
                 "statement": question.statement,
                 "statement_format": statement_format,
                 "statement_language": lang,
@@ -84,22 +91,23 @@ class UCode:
                                                ("sub_question" if question.sub_question else "")
             }
 
-            new_option_format = False
-            if not isinstance(question.options, list):
-                new_option_format = True
-            else:
-                for i, option in enumerate(question.options):
-                    if not isinstance(option, QuestionOption):
-                        # CLog.error("Option not valid:")
-                        # print(question.to_json())
-                        new_option_format = True
-                        break
-                    if not option.content:
-                        new_option_format = True
-                        break
-                    data[f"option{i + 1}"] = option.content
-                    if option.is_correct:
-                        data['answer'] = f"{i + 1}"
+            new_option_format = True
+            # new_option_format = False
+            # if not isinstance(question.options, list):
+            #     new_option_format = True
+            # else:
+            #     for i, option in enumerate(question.options):
+            #         if not isinstance(option, QuestionOption):
+            #             # CLog.error("Option not valid:")
+            #             # print(question.to_json())
+            #             new_option_format = True
+            #             break
+            #         if not option.content:
+            #             new_option_format = True
+            #             break
+            #         data[f"option{i + 1}"] = option.content
+            #         if option.is_correct:
+            #             data['answer'] = f"{i + 1}"
 
             question_json = json.loads(question.to_json())
             if question.solution:
@@ -136,8 +144,9 @@ class UCode:
             data['slug'] = make_slug(problem.name)
 
         response = self.s.post(url, json=data, headers=self._headers)
-
-        print(response.status_code)
+        # print("url:", url)
+        # print("payload:", json.dumps(data))
+        print("status code", response.status_code)
         # print(response.text)
         res = response.json()
         # print(res)
@@ -149,8 +158,9 @@ class UCode:
 
         if isinstance(problem, Problem):
             # upload testcase
-            for i, testcase in enumerate(problem.testcases):
-                self.upload_testcase(question_id, testcase, is_sample=True)
+            # for i, testcase in enumerate(problem.testcases):
+            #     self.upload_testcase(question_id, testcase, is_sample=i<2)
+            self.upload_testcases(question_id, problem.testcases)
 
         if isinstance(problem, Problem):
             if problem.translations:
@@ -167,7 +177,12 @@ class UCode:
                         "constraints": tran_problem.constraints,
 
                     }
+                    # print("url:", url)
+                    # print("payload:", json.dumps(data))
+
                     response = self.s.post(url, json=data, headers=self._headers)
+                    print("status code", response.status_code)
+                    # print(response.text)
                     res = response.json()
                     if res['success']:
                         tran_question_id = res['data']['id']
@@ -187,6 +202,33 @@ class UCode:
 
         return question_ids
 
+    def upload_testcases(self, problem_id, testcases: List[TestCase], samples=2, score=10):
+        url = self.get_api_url(f"/question/{problem_id}/upload-testcases")
+        testcase_data = []
+        for i, testcase in enumerate(testcases):
+            t = {
+                "name": testcase.name,
+                "explanation": testcase.explanation,
+                "input": testcase.input,
+                "output": testcase.output,
+                "score": score,
+                "is_sample": i < samples
+            }
+            testcase_data.append(t)
+        payload = {
+            "testcases": testcase_data
+        }
+
+        response = self.s.post(url, json=payload, headers=self._headers)
+        print("status_code:", response.status_code)
+        print(response.text)
+        res = response.json()
+        # print(res)
+        if res['success']:
+            print(len(testcases), "testcase(s) upload successfully")
+        else:
+            CLog.error("Cannot create testcase:" + json.dumps(res))
+
     def upload_testcase(self, problem_id, testcase: TestCase, is_sample=True, score=10):
         url = self.get_api_url(f"/question/{problem_id}/testcase")
         data = {
@@ -224,7 +266,8 @@ class UCode:
 
         return api_url, token
 
-    def create_chapter(self, course_id, chapter_name, slug=None, parent_id=None, status="draft", _type="chapter"):
+    def create_chapter(self, course_id, chapter_name, slug=None, parent_id=None,
+                       status="draft", _type="chapter", is_free=True):
         if not slug:
             slug = make_slug(chapter_name)
 
@@ -234,7 +277,7 @@ class UCode:
             "name": chapter_name,
             "is_preview": False,
             # "content_type": "video",
-            "is_free": True,
+            "is_free": is_free,
             "slug": slug,
             "status": status
         }
@@ -254,7 +297,7 @@ class UCode:
     def create_lesson_item(self, course_id, chapter_id, lesson_name, slug=None,
                            desciption="", content="",
                            type="video", video_url="",
-                           status="draft"):
+                           status="draft", is_free=True):
         if not slug:
             slug = make_slug(lesson_name)
 
@@ -264,7 +307,7 @@ class UCode:
             "name": lesson_name,
             "is_preview": False,
             "content_type": type,
-            "is_free": True,
+            "is_free": is_free,
             "slug": slug,
             "status": status
         }
@@ -291,7 +334,7 @@ class UCode:
                 "content": content,
                 "content_format": "markdown",
                 "slug": slug,
-                "is_free": True,
+                "is_free": is_free,
                 "is_preview": False,
                 "visibility": "public"
             }
@@ -370,24 +413,42 @@ def iqsha(year, ucode_course_id):
                         # pass
 
 
+def create_public_problem():
+    problems = read_all_problems("/home/thuc/projects/ucode/weekly-algorithm-problems/week13",
+                                 translations=["vi"], load_testcase=True)
+
+    ucode = UCode("https://dev-api.ucode.vn/api", "743c1fce2615a4cb569dd57f86b73898")
+
+    print(len(problems))
+    for i, (problem_folder, problem) in enumerate(problems):
+        print(i+1, problem.name)
+        # print(problem.tags)
+        # print(problem.translations['vi'].statement)
+        print("Testcases: ", len(problem.testcases))
+        res = ucode.create_problem(lesson_id=None, problem=problem, lang="en", xp=-1, status="draft", is_server_judge=True)
+        print("res:", res)
+        # break
+
+
 if __name__ == "__main__":
-    ucode_courses = {
-        2: 42,
-        3: 43,
-        4: 44,
-        5: 45,
-        6: 46,
-        7: 47,
-        8: 48,
-        9: 49,
-        10: 50,
-        11: 51
-    }
+    create_public_problem()
+    # ucode_courses = {
+    #     2: 42,
+    #     3: 43,
+    #     4: 44,
+    #     5: 45,
+    #     6: 46,
+    #     7: 47,
+    #     8: 48,
+    #     9: 49,
+    #     10: 50,
+    #     11: 51
+    # }
     # ucode_courses = {
     #     2: 46
     # }
-    for y, course_id in ucode_courses.items():
-        iqsha(y, course_id)
+    # for y, course_id in ucode_courses.items():
+    #     iqsha(y, course_id)
 
     # create_chapters_mc1()
 
